@@ -2,9 +2,49 @@
 #
 #   file: lib/Dist/Zilla/PluginBundle/Author/VDB.pm
 
+#pod =encoding UTF-8
+#pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright © 2015 Van de Bugger
+#pod
+#pod This file is part of perl-Dist-Zilla-PluginBundle-Author-VDB.
+#pod
+#pod perl-Dist-Zilla-PluginBundle-Author-VDB is free software: you can redistribute it and/or modify
+#pod it under the terms of the GNU General Public License as published by the Free Software
+#pod Foundation, either version 3 of the License, or (at your option) any later version.
+#pod
+#pod perl-Dist-Zilla-PluginBundle-Author-VDB is distributed in the hope that it will be useful, but
+#pod WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+#pod PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#pod
+#pod You should have received a copy of the GNU General Public License along with
+#pod perl-Dist-Zilla-PluginBundle-Author-VDB. If not, see <http://www.gnu.org/licenses/>.
+#pod
+#pod =cut
 
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+#pod =head1 DESCRIPTION
+#pod
+#pod It is unlikely that someone else will want to use it, so I will not bother with documenting it, at
+#pod least for now.
+#pod
+#pod =option minimum_perl
+#pod
+#pod =option fake_release
+#pod
+#pod If true (C<1>), release will be a fake one, i. e. no external operations will be done:
+#pod C<UploadToCPAN> plugin will be replaced with C<FakeRelease> (which does nothing), C<ArchiveRelease>
+#pod will be skipped, and C<hg push> will not be performed.
+#pod
+#pod Option can be set trough F<dist.ini> file or with C<FAKE_RELEASE> environment variable.
+#pod
+#pod C<Bool>, optional, default value is C<0>.
+#pod
+#pod =for Pod::Coverage configure
+#pod
+#pod =cut
 
 package Dist::Zilla::PluginBundle::Author::VDB;
 
@@ -14,11 +54,15 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+# Require all the modules now to avoid unexpected failures in the middle of release.
 use Dist::Zilla::Plugin::Hook 0.005;    # We need Hook::PrereqSource.
+use IPC::System::Simple qw{};
+use Path::Tiny          qw{};
+use Perl::Version       qw{};
 
 has minimum_perl => (
     is          => 'ro',
@@ -153,8 +197,9 @@ sub configure {
 
         # Code
 
-        [ 'Test::Compile' ],
-            #fake_home => 1 ???
+        [ 'Test::Compile' => {
+            'fake_home' => 1,
+        } ],
 
         [ 'Test::Version' => {          # All modules have version.
             #~ 'is_strict' => 1,        # Does not work for trial releases.
@@ -209,7 +254,8 @@ sub configure {
         [ 'MinimumPerl' ],
 
         [ 'AutoPrereqs' ],
-        # [Prereqs::AuthorDeps]
+
+        [ 'Prereqs::AuthorDeps' ],
 
         [ 'Hook::PrereqSource' => {
             'hook' => [
@@ -260,10 +306,10 @@ sub configure {
         #   Release
         #
 
-        #~ [ 'RunExtraTests' ],          ; Does not work for me, see <https://github.com/dagolden/Dist-Zilla-Plugin-CheckExtraTests/issues/26>.
-
+        #~ [ 'RunExtraTests' ],         # Does not work for me, see <https://github.com/dagolden/Dist-Zilla-Plugin-CheckExtraTests/issues/26>.
         [ 'CheckExtraTests' ],          # So use CheckExtraTest meanwhile.
-        #~ [CheckChangesHasContent]
+
+        [ 'CheckChangesHasContent' ],
 
         [ 'TestRelease'     ],          # Unpack tarball and run tests.
 
@@ -345,10 +391,12 @@ sub configure {
 
         [ 'Hook::AfterRelease' => 'bump version' => {
             'hook' => [
-                q| use Path::Tiny;                                                          |,
-                q| my $next = ( eval( $dist->version ) + 0.000001 ) =~ s{(\d{3})\z}{_$1}r;  |,
-                q| path( 'VERSION' )->spew( $next );                                        |,
-                q| $self->log( [ 'Next release will be %s', $next ] );                      |,
+                q| use Path::Tiny;                                        |,
+                q| use Perl::Version;                                     |,
+                q| my $version = Perl::Version->new( $dist->version );    |,
+                q| $version->inc_alpha;                                   |,
+                q| path( 'VERSION' )->spew( $version );                   |,
+                q| $self->log( [ 'Next release will be %s', $version ] ); |,
             ],
         } ],
 
@@ -390,10 +438,26 @@ __PACKAGE__->meta->make_immutable();
 
 # doc/what.pod #
 
+#pod =encoding UTF-8
+#pod
+#pod =head1 WHAT?
+#pod
+#pod C<Dist-Zilla-PluginBundle-Author-VDB> (or just C<@Author::VDB>) is a C<Dist-Zilla> plugin bundle used by VDB.
+#pod
+#pod =cut
 
 # end of file #
 # doc/why.pod #
 
+#pod =encoding UTF-8
+#pod
+#pod =head1 WHY?
+#pod
+#pod I have published few distributions on CPAN. Every distribution have F<dist.ini> file. All the
+#pod F<dist.ini> files are very similar. Maintaining multiple very similar F<dist.ini> files is boring.
+#pod Plugin bundle solves the problem.
+#pod
+#pod =cut
 
 # end of file #
 
@@ -412,7 +476,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version 0.002, released on 2015-08-08 17:03 UTC.
+Version 0.003, released on 2015-08-09 19:26 UTC.
 
 =head1 WHAT?
 
